==> kleopatra-17.04.2.tar.xz: kleopatra-17.04.2/src/commands/keytocardcommand.h <==
/*  commands/keytocardcommand.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2017 Intevation GmbH

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_COMMANDS_KEYTOCARDCOMMAND_H__
#define __KLEOPATRA_COMMANDS_KEYTOCARDCOMMAND_H__

#include <commands/command.h>

#include <string>
#include <gpgme++/key.h>

namespace Kleo
{
namespace Commands
{

class KeyToCardCommand : public Command
{
    Q_OBJECT
public:
    KeyToCardCommand(const GpgME::Subkey &key, const std::string &serialno);
    ~KeyToCardCommand();

    static bool supported();


public Q_SLOTS:
    void keyToCardDone(const GpgME::Error &err);
    void deleteDone(const GpgME::Error &err);

private:
    void doStart() Q_DECL_OVERRIDE;
    void doCancel() Q_DECL_OVERRIDE;

private:
    class Private;
    inline Private *d_func();
    inline const Private *d_func() const;
};

}
}

#endif /* __KLEOPATRA_COMMANDS_KEYTOCARDCOMMAND_H__ */

==> kleopatra-17.08.3.tar.xz: kleopatra-17.08.3/src/commands/keytocardcommand.h <==
/*  commands/keytocardcommand.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2017 by Bundesamt für Sicherheit in der Informationstechnik
    Software engineering by Intevation GmbH

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_COMMANDS_KEYTOCARDCOMMAND_H__
#define __KLEOPATRA_COMMANDS_KEYTOCARDCOMMAND_H__

#include <commands/command.h>

#include <string>
#include <gpgme++/key.h>

namespace Kleo
{
namespace Commands
{

class KeyToCardCommand : public Command
{
    Q_OBJECT
public:
    KeyToCardCommand(const GpgME::Subkey &key, const std::string &serialno);
    ~KeyToCardCommand();

    static bool supported();


public Q_SLOTS:
    void keyToCardDone(const GpgME::Error &err);
    void deleteDone(const GpgME::Error &err);

private:
    void doStart() override;
    void doCancel() override;

private:
    class Private;
    inline Private *d_func();
    inline const Private *d_func() const;
};

}
}

#endif /* __KLEOPATRA_COMMANDS_KEYTOCARDCOMMAND_H__ */
